@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/src/routers/manualroute.h,v 1.5 2007/01/08 10:50:20 ph10 Exp $ */
+/* $Cambridge: exim/exim-src/src/routers/manualroute.h,v 1.7 2009/11/16 19:50:38 nm4 Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2007 */
+/* Copyright (c) University of Cambridge 1995 - 2009 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* Header for the manualroute router */
@@ -12,8 +12,10 @@
 /* Structure for the private options. */
 
 typedef struct {
+  int   hai_code;
   int   hff_code;
   BOOL  hosts_randomize;
+  uschar *host_all_ignored;
   uschar *host_find_failed;
   uschar *route_data;
   uschar *route_list;
